@@ -1,27 +1,28 @@
-# Import the library main init function
-from .__init__ import __version__
+"""EWC Commons Library
+
+A collection of common useful code library stuff & a showcase for learning.
+Also showcase how to use the Sophie subpackage module.
+"""
+# Import the current library version number.
+from .__init__ import __version__, _app_name_
 
 # Import the typing library so variables can be type cast
-from typing import List, Tuple
+from typing import List, Tuple, Any
 
 # Import the sys for args
 import sys
 
 # Import the Sophie launcher system needed
-from ewccommons.sophie import (
-    _TNGN_,
-    _CLI_Arg_Handled_,
-    SophieLauncher,
-    CLIUsageHandler,
-    launcher,
-)
+from ewccommons.sophie import get_launcher
+from ewccommons.sophie.usage import CLIUsageHandler
+from ewccommons.sophie.launcher import wrapped_launch_handler, SophieLauncher
 
 # Import the collection of available modules
 from ewccommons import dice
 from ewccommons import dicerolls
 from ewccommons import carddeck
 
-_app_name_: str = "EWC Commons Library"
+# Define some library & launch level variables
 _short_options_: str = "hvq:"
 _long_options_: List = [
     "help",
@@ -33,44 +34,27 @@ _long_options_: List = [
 ]
 
 
-def cli_argument_handler(
+def launch_option_handler(
+    opt: str,
+    arg: str,
     opts: Tuple,
     args: Tuple,
-    show_usage_help: _TNGN_,
-    show_version: _TNGN_,
-) -> _CLI_Arg_Handled_:
+) -> Tuple[Any, ...]:
     """
-    Handle the processing of the cli arguments.
+    Just handler the launch option
     """
-    enquiry: str = None
-    opt: str
-    arg: str
-    for opt, arg in opts:
-        if opt in ("-h", "--help"):
-            # Just show the usage help & halt
-            show_version()
-            show_usage_help()
-            sys.exit()
-        elif opt in ("-v", "--version"):
-            # Just show the version & halt
-            show_version()
-            sys.exit()
-        elif opt == "--dice":
-            # Run the dice main module function
-            dice.check_output()
-        elif opt == "--dicerolls":
-            # Convert the value to lower, split on space
-            # Add any unnamed arguments as potential included option values
-            ds: List[str] = arg.lower().split() + list(args)
-            # Supply the arguments to the dicerolls main function for handling
-            dicerolls.rolls(*ds)
-        elif opt == "--carddeck":
-            # Run the carddeck main module function
-            carddeck.spread_deck()
-        elif opt in ("-q", "--enquiry"):
-            # Assign the enquiry value
-            enquiry = arg
-    return enquiry, args
+    if opt == "--dice":
+        # Run the dice main module function
+        dice.check_output()
+    elif opt == "--dicerolls":
+        # Convert the value to lower, split on space
+        # Add any unnamed arguments as potential included option values
+        ds: List[str] = arg.lower().split() + list(args)
+        # Supply the arguments to the dicerolls main function for handling
+        dicerolls.rolls(*ds)
+    elif opt == "--carddeck":
+        # Run the carddeck main module function
+        carddeck.spread_deck()
 
 
 def help_text() -> str:
@@ -80,6 +64,7 @@ def help_text() -> str:
     TODO get this to read from a file???
 
     :return: The app help text multiline string.
+    :rtype: str
     """
     return "\n".join(
         [
@@ -98,7 +83,7 @@ def main(*args) -> None:
     sophie: SophieLauncher
     usage: CLIUsageHandler
     # Create a new app launcher & usage instance
-    sophie, usage = launcher(
+    sophie, usage = get_launcher(
         _usage=CLIUsageHandler,
         app_name=_app_name_,
         version=__version__,
@@ -126,8 +111,13 @@ def main(*args) -> None:
     )
     # Define the usage & types of variables to be used in this scope
     enquiry: str
-    enquiry, args = sophie.launch(cli_argument_handler)
-    print(enquiry, args)
+    handler_results: List[Tuple[Any, ...]]
+    other: Tuple
+    # enquiry, args = sophie.launch(cli_argument_handler)
+    enquiry, handler_results, other = sophie.launch(
+        wrapped_launch_handler(launch_option_handler)
+    )
+    print(enquiry, handler_results, other)
     # sophie.show_usage_help()
 
 
