@@ -17,8 +17,9 @@ from copy import copy
 # Import the random library
 import random
 
-# Import the Sophie ValueError generator
-from ewccommons.sophie import not_what_i_wanted
+# Import library stuff
+from ewccommons import str_lower_list
+from ewccommons.errors import not_what_i_wanted
 
 _Die_Faces_ = List[int]
 """Type Alias Definition
@@ -38,8 +39,10 @@ def roll_die(_die: _Die_Faces_) -> int:
     """
     Randomly choose a number from the x sided die face values.
 
-    :param _die: (_Die_Faces_) The list of die face side values.
+    :param _die: The list of die face side values.
+    :type _die: `ewccommons.dice._Die_Faces_`
     :return: A randomly chosen integer value from the die faces list.
+    :rtype: int
     """
     return random.choice(_die)
 
@@ -51,14 +54,23 @@ class Dice:
     Simulate rolling dice by randomly chosing a die face value.
     """
 
-    def __init__(self, sides: int, name: str = None, val: int = None) -> None:
+    def __init__(
+        self, sides: int, name: Optional[str] = None, val: Optional[int] = None
+    ) -> None:
         """Initialize the Dice object
 
         Set the dice name, the face values list & a starting face value.
 
         :param sides: The number of face sides for the dice instance.
-        :param name: An optional string name for the dice instance.
-        :param val: An optional starting rolled value for the dice instance.
+        :type sides: int
+        :param name: A string name for the dice instance, defaults to D#sides.
+        :type name: Optional[str], optional
+        :param val: A starting rolled value for the dice instance, defaults to random.
+        :type sides: Optional[int], optional
+        :raises: ValueError For invalid sides type.
+        :raises: ValueError If sides value is less than 2.
+        :raises: ValueError For invalid starting value.
+        :raises: ValueError If starting value is outside the side faces range.
         """
         # Verify the supplied sides data type is what we expect
         if not isinstance(sides, int):
@@ -97,28 +109,34 @@ class Dice:
 
     @property
     def name(self) -> str:
-        """
+        """Instance Property
+
         Get the name of the die.
 
         :return: The dice instance name.
+        :rtype: str
         """
         return self.__name
 
     @property
     def faces(self) -> _Die_Faces_:
-        """
+        """Instance Property
+
         Get the list of face values for the die.
 
         :return: The list of the dice instance face values.
+        :rtype: `ewccommons.dice._Die_Faces_`
         """
         return self.__face_values
 
     @property
     def rolled(self) -> int:
-        """
+        """Instance Property
+
         Get the rolled face value of the die.
 
         :return: The current rolled value of the dice instance.
+        :rtype: int
         """
         return self.__rolled
 
@@ -127,6 +145,7 @@ class Dice:
         Simulate rolling the die.
 
         :return: The rolled value of the dice instance.
+        :rtype: int
         """
         # Roll the die faces & set the value as the internal rolled value
         roll: int = roll_die(self.faces)
@@ -146,6 +165,7 @@ class Dice:
         Get a string to represent recreating this object.
 
         :return: A string representation capable of creating the dice instance.
+        :rtype: str
         """
         return f"{__class__}(sides={len(self)},name={self.__name},val={self.__rolled})"
 
@@ -154,6 +174,7 @@ class Dice:
         Get the object as a human readable string.
 
         :return: A Human readable string version of the dice instance.
+        :rtype: str
         """
         return f"{self.name} : {self.rolled}"
 
@@ -162,6 +183,7 @@ class Dice:
         Return the number of faces the die has.
 
         :return: The number of face sides the dice instance has.
+        :rtype: int
         """
         return len(self.__face_values)
 
@@ -170,7 +192,9 @@ class Dice:
         Check to see if the dice roll is equal to the operand.
 
         :param o: The operand being compared with.
+        :type o: object
         :return: True when compared to the dice instance rolled value is True.
+        :rtype: bool
         """
         return self.__rolled == o
 
@@ -179,7 +203,9 @@ class Dice:
         Check to see if the dice roll is not equal to the operand.
 
         :param o: The operand being compared with.
+        :type o: object
         :return: True when compared to the dice instance rolled value is True.
+        :rtype: bool
         """
         return self.__rolled != o
 
@@ -188,7 +214,9 @@ class Dice:
         Check to see if the dice roll is less than the operand.
 
         :param o: The operand being compared with.
+        :type o: object
         :return: True when compared to the dice instance rolled value is True.
+        :rtype: bool
         """
         return self.__rolled < o
 
@@ -197,7 +225,9 @@ class Dice:
         Check to see if the dice roll is greater than the operand.
 
         :param o: The operand being compared with.
+        :type o: object
         :return: True when compared to the dice instance rolled value is True.
+        :rtype: bool
         """
         return self.__rolled > o
 
@@ -206,7 +236,9 @@ class Dice:
         Check to see if the dice roll is less than the operand.
 
         :param o: The operand being compared with.
+        :type o: object
         :return: True when compared to the dice instance rolled value is True.
+        :rtype: bool
         """
         return self.__rolled <= o
 
@@ -215,7 +247,9 @@ class Dice:
         Check to see if the dice roll is greater than the operand.
 
         :param o: The operand being compared with.
+        :type o: object
         :return: True when compared to the dice instance rolled value is True.
+        :rtype: bool
         """
         return self.__rolled >= o
 
@@ -237,7 +271,8 @@ class DiceShaker:
 
         Setup the empty DiceShaker and add any optional starting dice.
 
-        :param _dice: An optional list of existing dice instances.
+        :param _dice: A list of existing dice instances, defaults to None.
+        :type _dice: Optional[`ewccommons.dice._Dice_`], optional
         """
         # Define the instance properties used, list of dice,
         # current roll total, current min & max roll values
@@ -250,21 +285,58 @@ class DiceShaker:
             # Use the supplied list of dice to populate the shaker
             self.populate(_dice)
 
+    @property
+    def min_roll(self) -> int:
+        """Instance Property
+
+        Return the minimum value the shaker can roll.
+
+        :return: The minimum combined roll value the shaker can roll.
+        :rtype: int
+        """
+        return self.__min
+
+    @property
+    def max_roll(self) -> int:
+        """Instance Property
+
+        Return the maximum value the shaker can roll.
+
+        :return: The maximum combined roll value the shaker can roll.
+        :rtype: int
+        """
+        return self.__max
+
+    @property
+    def roll_total(self) -> int:
+        """Instance Property
+
+        Return the total of the dice rolled.
+
+        :return: The total combined rolled dice value.
+        :rtype: int
+        """
+        return self.__total
+
     def populate(self, _dice: _Dice_) -> None:
         """
         Add a subset list of dice to the shaker.
 
         :param _dice: A list of existing dice instances.
+        :type _dice: `ewccommons.dice._Dice_`
         """
         for _die in _dice:
             self.add(_die)
 
-    def add(self, _die: Dice, amount: int = 1) -> None:
+    def add(self, _die: Dice, amount: Optional[int] = 1) -> None:
         """
         Add a die to dice shaker.
 
         :param _die: The dice instance to add to the shaker.
-        :param amount: The number of dice instance copies to add.
+        :type _die: :class:`ewccommons.dice.Dice`
+        :param amount: The number of dice instance copies to add, defaults to 1.
+        :type amount: Optional[int], optional
+        :raises: ValueError If the amount is less than 1.
         """
         # Make sure we are adding a positive number
         if amount < 1:
@@ -281,33 +353,6 @@ class DiceShaker:
         self.__min += min(_die.faces) * amount
         self.__max += max(_die.faces) * amount
 
-    @property
-    def min_roll(self) -> int:
-        """
-        Return the minimum value the shaker can roll.
-
-        :return: The minimum combined roll value the shaker can roll.
-        """
-        return self.__min
-
-    @property
-    def max_roll(self) -> int:
-        """
-        Return the maximum value the shaker can roll.
-
-        :return: The maximum combined roll value the shaker can roll.
-        """
-        return self.__max
-
-    @property
-    def roll_total(self) -> int:
-        """
-        Return the total of the dice rolled.
-
-        :return: The total combined rolled dice value.
-        """
-        return self.__total
-
     def empty_shaker(self) -> None:
         """
         Remove any dice from the shaker list.
@@ -333,6 +378,7 @@ class DiceShaker:
         Shake & roll the dice to get the results.
 
         :return: A tuple of the roll total and the individual dice rolls.
+        :rtype: Tuple[int, Tuple]
         """
         # Make sure the dice have been shaken
         self.shake()
@@ -355,6 +401,7 @@ class DiceShaker:
         Get a string to represent recreating this object.
 
         :return: A string representation capable of creating the shaker instance.
+        :rtype: str
         """
         return f"{__class__}({repr(self.__dice)})"
 
@@ -363,6 +410,7 @@ class DiceShaker:
         Get the object as a human readable string.
 
         :return: A Human readable string version of the dice shaker instance.
+        :rtype: str
         """
         # TODO work out how to collect the rolled values to add the strings
         return "\n".join(
@@ -378,6 +426,9 @@ class DiceShaker:
     def __len__(self) -> int:
         """
         Return the number of dice.
+
+        :return: The number of Dice objects in the shaker.
+        :rtype: int
         """
         return len(self.__dice)
 
@@ -386,43 +437,75 @@ class DiceShaker:
         Get a specific die from the shaker.
 
         :param position: The index position to get the dice instance from.
+        :type position: int
         :return: The dice instance.
+        :rtpe: :class:`Dice`
         """
         return self.__dice[position]
 
     def __eq__(self, o: object) -> bool:
         """
         Check to see if the dice roll total is equal to the operand.
+
+        :param o: The operand being compared with.
+        :type o: object
+        :return: True when compared to the rolled total value is True.
+        :rtype: bool
         """
         return self.__total == o
 
     def __ne__(self, o: object) -> bool:
         """
         Check to see if the dice roll total is not equal to the operand.
+
+        :param o: The operand being compared with.
+        :type o: object
+        :return: True when compared to the rolled total value is True.
+        :rtype: bool
         """
         return self.__total != o
 
     def __lt__(self, o: object) -> bool:
         """
         Check to see if the dice roll total is less than the operand.
+
+        :param o: The operand being compared with.
+        :type o: object
+        :return: True when compared to the rolled total value is True.
+        :rtype: bool
         """
         return self.__total < o
 
     def __gt__(self, o: object) -> bool:
         """
         Check to see if the dice roll total is greater than the operand.
+
+        :param o: The operand being compared with.
+        :type o: object
+        :return: True when compared to the rolled total value is True.
+        :rtype: bool
         """
         return self.__total > o
 
     def __le__(self, o: object) -> bool:
         """
-        Check to see if the dice roll total is less than the operand.
+        Check to see if the dice roll total is less than or equal the operand.
+
+        :param o: The operand being compared with.
+        :type o: object
+        :return: True when compared to the rolled total value is True.
+        :rtype: bool
         """
         return self.__total <= o
 
     def __ge__(self, o: object) -> bool:
         """
-        Check to see if the dice roll total is greater than the operand.
+        Check to see if the dice roll total is greater than or equal the operand.
+
+        :param o: The operand being compared with.
+        :type o: object
+        :return: True when compared to the rolled total value is True.
+        :rtype: bool
         """
         return self.__total >= o
 
@@ -455,7 +538,7 @@ def main() -> None:
     Run as a module and convert any CLI arguments to lowercase.
     """
     # Call the main function with any command line arguments after the module name
-    check_output(*[str(_).lower() for _ in sys.argv[1:]])
+    check_output(*str_lower_list(sys.argv[1:]))
 
 
 # Make sure the script is being called as a script & not being imported into
